@@ -11,7 +11,7 @@ from hud.cli.eval import (
     build_agent,
     run_single_task,
 )
-from hud.types import Task, Trace
+from hud.types import AgentType, Task, Trace
 
 
 class TestBuildAgent:
@@ -26,7 +26,7 @@ class TestBuildAgent:
             mock_runner.return_value = mock_instance
 
             # Test with verbose=False
-            result = build_agent("integration_test", verbose=False)
+            result = build_agent(AgentType.INTEGRATION_TEST, verbose=False)
 
             mock_runner.assert_called_once_with(verbose=False)
             assert result == mock_instance
@@ -40,9 +40,9 @@ class TestBuildAgent:
             mock_runner.return_value = mock_instance
 
             # Test with verbose=False
-            result = build_agent("claude", verbose=False)
+            result = build_agent(AgentType.CLAUDE, verbose=False)
 
-            mock_runner.assert_called_once_with(model="claude-sonnet-4-20250514", verbose=False)
+            mock_runner.assert_called_once_with(model="claude-sonnet-4-5", verbose=False)
             assert result == mock_instance
 
     def test_builds_claude_agent_with_custom_model_and_allowed_tools(self) -> None:
@@ -55,19 +55,39 @@ class TestBuildAgent:
 
             # Test with verbose=False
             result = build_agent(
-                "claude",
-                model="claude-sonnet-4-20250514",
+                AgentType.CLAUDE,
+                model="claude-sonnet-4-5",
                 allowed_tools=["act"],
                 verbose=True,
             )
 
             mock_runner.assert_called_once_with(
-                model="claude-sonnet-4-20250514",
+                model="claude-sonnet-4-5",
                 allowed_tools=["act"],
                 verbose=True,
             )
             assert result == mock_instance
 
+    def test_builds_gemini_agent(self) -> None:
+        """Test building a Gemini agent."""
+        with patch("hud.agents.GeminiAgent") as mock_runner:
+            mock_instance = Mock()
+            mock_runner.return_value = mock_instance
+
+            result = build_agent(
+                AgentType.GEMINI,
+                model="gemini-test",
+                allowed_tools=["gemini_computer"],
+                verbose=True,
+            )
+
+            mock_runner.assert_called_once_with(
+                model="gemini-test",
+                verbose=True,
+                allowed_tools=["gemini_computer"],
+            )
+            assert result == mock_instance
+
 
 class TestRunSingleTask:
     """Test the run_single_task function."""
@@ -97,7 +117,7 @@ class TestRunSingleTask:
             patch("hud.cli.eval.find_environment_dir", return_value=None),
             patch("hud.cli.eval.hud.trace"),
         ):
-            await run_single_task("test.json", agent_type="integration_test", max_steps=10)
+            await run_single_task("test.json", agent_type=AgentType.INTEGRATION_TEST, max_steps=10)
 
             # Verify agent.run was called with the task containing agent_config
             mock_agent.run.assert_called_once()
@@ -119,7 +139,7 @@ class TestRunSingleTask:
             mock_grouped.return_value = [{"task": mock_task, "rewards": [1.0, 0.5]}]
 
             await run_single_task(
-                "test.json", agent_type="integration_test", group_size=3, max_steps=10
+                "test.json", agent_type=AgentType.INTEGRATION_TEST, group_size=3, max_steps=10
             )
 
             # Verify run_tasks_grouped was called with correct group_size
@@ -175,9 +195,21 @@ class TestToolFiltering:
     async def test_no_filters_returns_all_tools(self, mock_mcp_client, mock_model_client) -> None:
         """Test that no filters in agent_config returns all tools."""
         tools = [
-            types.Tool(name="tool1", description="Tool 1", inputSchema={}),
-            types.Tool(name="tool2", description="Tool 2", inputSchema={}),
-            types.Tool(name="debug_tool", description="Debug", inputSchema={}),
+            types.Tool(
+                name="tool1",
+                description="Tool 1",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="tool2",
+                description="Tool 2",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="debug_tool",
+                description="Debug",
+                inputSchema={"type": "object", "properties": {}},
+            ),
         ]
 
         result = await self._run_agent_with_tools(mock_mcp_client, mock_model_client, tools)
@@ -190,9 +222,21 @@ class TestToolFiltering:
     ) -> None:
         """Test that allowed_tools in agent_config filters to matching patterns."""
         tools = [
-            types.Tool(name="screenshot_take", description="Tool 1", inputSchema={}),
-            types.Tool(name="screenshot_full", description="Tool 2", inputSchema={}),
-            types.Tool(name="click", description="Tool 3", inputSchema={}),
+            types.Tool(
+                name="screenshot_take",
+                description="Tool 1",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="screenshot_full",
+                description="Tool 2",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="click",
+                description="Tool 3",
+                inputSchema={"type": "object", "properties": {}},
+            ),
         ]
         agent_config = {"allowed_tools": ["screenshot_*"]}
 
@@ -209,9 +253,21 @@ class TestToolFiltering:
     ) -> None:
         """Test that disallowed_tools in agent_config excludes matching patterns."""
         tools = [
-            types.Tool(name="tool1", description="Tool 1", inputSchema={}),
-            types.Tool(name="debug_tool", description="Tool 2", inputSchema={}),
-            types.Tool(name="internal_secret", description="Tool 3", inputSchema={}),
+            types.Tool(
+                name="tool1",
+                description="Tool 1",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="debug_tool",
+                description="Tool 2",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="internal_secret",
+                description="Tool 3",
+                inputSchema={"type": "object", "properties": {}},
+            ),
         ]
         agent_config = {"disallowed_tools": ["debug_*", "internal_*"]}
 
@@ -228,9 +284,21 @@ class TestToolFiltering:
     ) -> None:
         """Test that both filters in agent_config work together (disallowed takes precedence)."""
         tools = [
-            types.Tool(name="browser_click", description="Tool 1", inputSchema={}),
-            types.Tool(name="browser_debug", description="Tool 2", inputSchema={}),
-            types.Tool(name="system_click", description="Tool 3", inputSchema={}),
+            types.Tool(
+                name="browser_click",
+                description="Tool 1",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="browser_debug",
+                description="Tool 2",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="system_click",
+                description="Tool 3",
+                inputSchema={"type": "object", "properties": {}},
+            ),
         ]
         agent_config = {"allowed_tools": ["browser_*"], "disallowed_tools": ["*_debug"]}
 
@@ -249,11 +317,31 @@ class TestRunDatasetToolFiltering:
     def all_tools(self):
         """Fixture for a standard set of tools."""
         return [
-            types.Tool(name="browser_click", description="Click", inputSchema={}),
-            types.Tool(name="browser_type", description="Type", inputSchema={}),
-            types.Tool(name="browser_debug", description="Debug", inputSchema={}),
-            types.Tool(name="system_screenshot", description="Screenshot", inputSchema={}),
-            types.Tool(name="system_execute", description="Execute", inputSchema={}),
+            types.Tool(
+                name="browser_click",
+                description="Click",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="browser_type",
+                description="Type",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="browser_debug",
+                description="Debug",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="system_screenshot",
+                description="Screenshot",
+                inputSchema={"type": "object", "properties": {}},
+            ),
+            types.Tool(
+                name="system_execute",
+                description="Execute",
+                inputSchema={"type": "object", "properties": {}},
+            ),
         ]
 
     @pytest.fixture
@@ -332,6 +420,7 @@ class TestRunDatasetToolFiltering:
             patch.object(ClaudeAgent, "_run_context", mock_run_context),
             patch.object(ClaudeAgent, "call_tools", mock_call_tools),
             patch("hud.clients.MCPClient", return_value=mock_client_instance),
+            patch("hud.settings.settings.anthropic_api_key", "sk-test-key"),
         ):
             # Run the dataset
             await run_dataset(
@@ -400,6 +489,7 @@ class TestRunDatasetToolFiltering:
             patch.object(ClaudeAgent, "_run_context", mock_run_context),
             patch.object(ClaudeAgent, "call_tools", mock_call_tools),
             patch("hud.clients.MCPClient", return_value=mock_client_instance),
+            patch("hud.settings.settings.anthropic_api_key", "sk-test-key"),
         ):
             # Run the dataset
             await run_dataset(
@@ -432,6 +522,9 @@ class TestRunDatasetToolFiltering:
             )
 
 
+SYSTEM_PROMPT = "You are an assistant that can use tools to help the user. You will be given a task and you will need to use the tools to complete the task."  # noqa: E501
+
+
 class TestSystemPromptHandling:
     """Test system prompt handling through run_dataset flow."""
 
@@ -475,7 +568,6 @@ class TestSystemPromptHandling:
     ) -> None:
         """Test that task system_prompt is appended when agent has default system prompt."""
         from hud.agents import ClaudeAgent
-        from hud.agents.base import GLOBAL_SYSTEM_PROMPT
         from hud.datasets.runner import run_dataset
 
         task_system_prompt = "Task prompt"
@@ -490,9 +582,7 @@ class TestSystemPromptHandling:
         }
 
         # Agent config with no custom system_prompt (will use default)
-        agent_init_config = {
-            "validate_api_key": False,
-        }
+        agent_init_config = {"validate_api_key": False, "system_prompt": SYSTEM_PROMPT}
 
         with (
             patch("hud.job"),
@@ -500,6 +590,7 @@ class TestSystemPromptHandling:
             patch.object(ClaudeAgent, "_run_context", mock_run_context),
             patch.object(ClaudeAgent, "call_tools", mock_call_tools),
             patch("hud.clients.MCPClient", return_value=mock_mcp_client),
+            patch("hud.settings.settings.anthropic_api_key", "sk-test-key"),
         ):
             # Run the dataset
             await run_dataset(
@@ -517,7 +608,7 @@ class TestSystemPromptHandling:
             # Verify the task system prompt was appended
             assert captured_agent.system_prompt.endswith(f"\n\n{task_system_prompt}")
             # Verify it starts with the base global system prompt
-            assert captured_agent.system_prompt.startswith(GLOBAL_SYSTEM_PROMPT)
+            assert captured_agent.system_prompt.startswith(SYSTEM_PROMPT)
 
     @pytest.mark.asyncio
     async def test_both_agent_and_task_system_prompts(
@@ -551,6 +642,7 @@ class TestSystemPromptHandling:
             patch.object(ClaudeAgent, "_run_context", mock_run_context),
             patch.object(ClaudeAgent, "call_tools", mock_call_tools),
             patch("hud.clients.MCPClient", return_value=mock_mcp_client),
+            patch("hud.settings.settings.anthropic_api_key", "sk-test-key"),
         ):
             # Run the dataset
             await run_dataset(
